
.. py:currentmodule:: pythreejs

WebGLShadowMap
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: WebGLShadowMap()
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/renderers/webgl/WebGLShadowMap


    .. py:attribute:: enabled

        .. sourcecode:: python

            Bool(False, allow_none=False).tag(sync=True)

    .. py:attribute:: type

        .. sourcecode:: python

            Enum(ShadowTypes, "PCFShadowMap", allow_none=False).tag(sync=True)

    .. py:attribute:: renderReverseSided

        .. sourcecode:: python

            Bool(False, allow_none=False).tag(sync=True)

    .. py:attribute:: renderSingleSided

        .. sourcecode:: python

            Bool(True, allow_none=False).tag(sync=True)

